@@ -12,11 +12,13 @@ pub use cluster_role_binding::ClusterRoleBindingExt;
 pub use configmap::ConfigMapExt;
 pub use deployment::DeploymentExt;
 pub use namespace::NamespaceExt;
+pub use policy_rule::PolicyRuleExt;
 pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
+pub use role_ref::RoleRefExt;
 pub use secret::SecretExt;
 pub use service_account::ServiceAccountExt;
-pub use policy_rule::PolicyRuleExt;
+pub use subject::SubjectExt;
 
 mod cluster_role;
 mod cluster_role_binding;
@@ -26,8 +28,10 @@ mod namespace;
 mod policy_rule;
 mod role;
 mod role_binding;
+mod role_ref;
 mod secret;
 mod service_account;
+mod subject;
 
 pub trait ResourceExt {
     fn metadata(name: impl ToString) -> metav1::ObjectMeta {
